# PyTorch implementation of Reservoir Computing models

## ESN

Implementation of a basic Echo State Network without output feedback connections.

 - LUKOŠEVIČIUS, Mantas; JAEGER, Herbert. Reservoir computing approaches to recurrent neural network training. Computer Science Review, 2009, 3.3: 127-149.